PRO PLANETS_SEED, DISTR, NSEED, ARANGE, MRANGE, MSTAR, SEED_GEN, $
ALPHA=ALPHA, BETA=BETA


;+
; NAME: PLANETS_SEED

; PURPOSE:

; EXPLANATION:

; CALLING SEQUENCE: PLANETS_SEED, DISTR, NSEED, ARANGE, MRANGE, MSTAR, SEED_GEN, $
;                   ALPHA=ALPHA, BETA=BETA
; INPUTS:
;       ARANGE - semi-major axis = [a0, a1] to be explored
;       MRANGE - mass range to be explored (Mjup) = [m0, m1]
;        MSTAR - stellar mass (Msun)
;        DISTR - chosen planet/mass distribution. It can be set to
;               a) 'C08' to use the distribution from Cumming et
;               al. 2008 
;               b) 'LG03' to use  the distribution from
;               Lineweaver & Grether 2003
;               c) 'CUSTOM' to set some other values of the power-low
;               index (alpha for the mass distribution and beta for
;               the period distribution) that have to be entered
;       NSEED - number of mass-period pairs to be generated 
;    SEED_GEN - Name of the file in which the seed generation must be
;               saved
; OPTIONAL INPUT KEYWORDS:
;       alpha - exponent for the mass distribution, to be set if
;               DISTR='CUSTOM'
;        beta - exponent for the period distribution, to be set if
;               DISTR='CUSTOM'
; OUTPUTS:
; 
; RESTRICTIONS:
;
; PROCEDURES CALLED: randomp()
;                   
;       
;
; REVISION HISTORY:
;       Written         
;       Modified        
;-

rsun=6.95508E8 ; Solar radius (m)
rjup=7.13E7    ; Jupiter radius (m)
rear=6.378E6   ; Earth radius (m)
rje=rjup/rear  ; Jupiter radius (Rear)
rsj=rsun/rjup  ; Sun radius (Rjup)
au=1.496E11    ; Astronomical Unit (m)


prange=(365.25*arange^(3.D/2.D))/(Mstar[0]^(1.D/2.D))

period_low=prange[0]
period_cut=prange[1]
mass_cut_l=mrange[0]
mass_cut_h=mrange[1]



IF DISTR EQ 'C08' then begin
;from Cumming et al. 2008PASP..120..531C
alpha=-1.31
beta=-0.74
period_ref=1826.
mass_ref=0.3
frac_planet=0.085
END

IF DISTR EQ 'LG03' then begin
; Lineweaver et al. 2003ApJ...598.1350L
alpha = -1.8
beta = -0.3
period_ref = 4748.25
mass_ref = 0.3
frac_planet = 0.09
END

IF DISTR EQ 'CUSTOM' then begin
alpha=alpha
beta=beta
print, 'you are using the following custom distribution '
print, 'alpha = ', string(alpha, format='(f7.3)'), '; beta = ', string(beta, format='(f7.3)')
frac_final=1
goto, nofrac
END


mt1=(1/(alpha+1))*(mass_cut_h^(alpha+1)-mass_ref^(alpha+1))
mt2=(1/(alpha+1))*(mass_cut_h^(alpha+1)-mass_cut_l^(alpha+1))
mass_term=mt2/mt1

pt1=(1/(beta+1))*(period_ref^(beta+1)-period_low^(beta+1))
pt2=(1/(beta+1))*(period_cut^(beta+1)-period_low^(beta+1))
period_term=pt2/pt1

frac_final=frac_planet*mass_term*period_term ; predicted fraction of planets, 
                                             ; normalized to the RV value. 

nofrac:
;;;;;;;;;;;;, mass ;;;;;;;;;;;;;;;;;;;;;;;;;;;
RANDOMP, mass, alpha, nseed, RANGE_X = [mass_cut_l,mass_cut_h]

;;;;;;;;;;;;, period ;;;;;;;;;;;;;;;;;;;;;;;;;;;
RANDOMP, p, beta, nseed, RANGE_X = [period_low,period_cut] 

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

gengrid:
;print, 'output file = ', seed_gen
;print, '###### END OF THE SEED GENERATION ######'

s=sort(p)
p=p(s)
ss=sort(mass)
mass=mass(ss)
a=((p/365.25D)^(2.D/3.D))*mstar^(1.D/3.D) 
save, filename=seed_gen, mass, p, a, frac_final

end
